@@ -5,7 +5,11 @@ use MooseX::App qw(Color);
 with 'HPC::Runner::Command::Utils::Plugin';
 with 'HPC::Runner::Command::Utils::ManyConfigs';
 
-our $VERSION = '3.1.1';
+option '+config_base' => (
+    default       => '.hpcrunner',
+);
+
+our $VERSION = '3.1.2';
 
 app_strict 0;
 
